==> servicecatalog-0.20.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/PortfolioShareResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolioshare.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-13T10:23:12.492Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.PortfolioShareResource")
public class PortfolioShareResource extends software.amazon.awscdk.Resource {
    protected PortfolioShareResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::PortfolioShare``.
     * @param parent the ``cdk.Construct`` this ``PortfolioShareResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``PortfolioShareResource``
     */
    public PortfolioShareResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getPortfolioShareId() {
        return this.jsiiGet("portfolioShareId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResourceProps.class);
    }
}

==> servicecatalog-0.21.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/PortfolioShareResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @deprecated "cloudformation.PortfolioShareResource" will be deprecated in a future release in favor of "CfnPortfolioShare" (see https://github.com/awslabs/aws-cdk/issues/878)
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolioshare.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:28:54.841Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.PortfolioShareResource")
public class PortfolioShareResource extends software.amazon.awscdk.Resource {
    protected PortfolioShareResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::PortfolioShare``.
     * @param parent the ``cdk.Construct`` this ``PortfolioShareResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``PortfolioShareResource``
     */
    public PortfolioShareResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getPortfolioShareId() {
        return this.jsiiGet("portfolioShareId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioShareResourceProps.class);
    }
}
